<?php

include('functions/comments.php');
include('functions/widgets/about.php');

function themejam_setup() {
	
	add_theme_support( 'automatic-feed-links' );
	
	// Featured Image
	add_theme_support( 'post-thumbnails' );

	set_post_thumbnail_size( 125, 125, true ); 

	if (!isset($content_width))
		$content_width = 940;

	//Menu 
	register_nav_menu('main-nav', 'Main Navigation');
	
    add_editor_style( 'styles/editor-style.css' );

}
add_action( 'after_setup_theme', 'themejam_setup' );

// Theme Options Page
$themename = "Noble";
$shortname = "nb";
$siteurl   = home_url();

$tj_categories_obj = get_categories('hide_empty=0');
$tj_categories     = array();

foreach ($tj_categories_obj as $tj_cat) {
	$tj_categories[$tj_cat->cat_ID] = $tj_cat->cat_name;
}

$categories_tmp = array_unshift($tj_categories, "Select a category:");

$options = array (
	# General Options
	array(    
		"type"  => "set-open",
		"class" => "general",
		"name"  => "General Options"),
	array(    
		"type" => "text",
		"name" => "RSS URL",
		"desc" => "Enter your RSS Feed URL here.  Leave it blank to disable the RSS link.",
		"id"   => $shortname."_feedburner_url",
		"std"  => ""),
	array(    
		"type" => "text",
		"name" => "Email Address Link",
		"desc" => "If you'd like the email link to be a direct mail link (mailto:), enter your email address here.",
		"id"   => $shortname."_email_address",
		"std"  => ""),
	array(    
		"type" => "text",
		"name" => "Email Link URL",
		"desc" => "If you'd like the email link to point to something other than an email address (for example, a Feedburner email feed link), enter that URL here.",
		"id"   => $shortname."_email_url",
		"std"  => ""),
	array(
		"type" => "textarea",
		"name" => "Custom CSS",
		"desc" => "Enter your own custom CSS code to overwrite any theme styles.<br />
		If you prefer to use your code editor, use the included /css/custom.css",
		"id"   => $shortname."_custom_css"),
	array("type" => "set-close"),

	# Display Options
	array(    
		"type"  => "set-open",
		"class" => "display",
		"name"  => "Display Options"),
	array(  
		"type" => "select",
		"name" => "Blog Posts Listing Preference",
		"desc" => "Display the content or the excerpt on your posts pages.",
		"id"   => $shortname."_content_or_excerpt",
		"options" => array("Content", "Excerpt"),
		"std"  => "Content"),
	array("type" => "set-close")
);

function themejam_options() {
	
    global $themename, $shortname, $options;
    
	if ( isset($_GET['page']) && $_GET['page'] == basename(__FILE__) ) {
        if ( isset($_REQUEST['action']) && 'save' == $_REQUEST['action'] ) {
			print_r($options);
			foreach ($options as $value) {
				if(array_key_exists('id', $value))
					update_option( $value['id'], $_REQUEST[ $value['id'] ] );
			}
			
			foreach ($options as $value) {
				if(array_key_exists('id', $value))
					if( isset( $_REQUEST[ $value['id'] ] ) ) {
						update_option( $value['id'], $_REQUEST[ $value['id'] ]  );
					} else {
						delete_option( $value['id'] );
					}
			}
            
			header("Location: themes.php?page=functions.php&saved=true");
            die;
        } else if( isset($_REQUEST['action']) && 'reset' == $_REQUEST['action'] ) {
            
			foreach ($options as $value) {
                delete_option( $value['id'] );
			}
            
			header("Location: themes.php?page=functions.php&reset=true");
            die;
        }
    }
    add_theme_page($themename."", "".$themename." Options", 'edit_themes', basename(__FILE__), 'mytheme_admin');
}

function mytheme_admin() {
    global $themename, $shortname, $options;
    if (isset($_REQUEST['saved']))
		echo '<div id="message" class="updated fade"><p><strong>'.$themename.' settings saved.</strong></p></div>';
    if (isset($_REQUEST['reset']))
		echo '<div id="message" class="updated fade"><p><strong>'.$themename.' settings reset.</strong></p></div>';
	?>
	
	<?php 
	wp_enqueue_style('options-panel-css', 
						get_template_directory_uri() . '/functions/tj-options-panel.css');
	wp_enqueue_script('jquery');
	wp_enqueue_script('options-panel-js', 
						get_template_directory_uri() . '/js/tj-options-panel.js', 
						array( 'jquery' )); ?>

	<div class="wrap">
	  <div id="poststuff">
	
		<h2><?php echo $themename; ?> Options</h2>
		
		<div class="postbox options-nav clearfix">
		
			<ul class="clearfix" id="nav">
				<?php foreach ($options as $value) {
						switch ( $value['type'] ) {
							case "set-open":
								printf('<li><a href="#%s">%s</a></li>', $value['class'], $value['name']);
								break; 
						}
					  } ?>
			</ul>
		
		</div><!--/ .postbox -->
	
		<form method="post">
		<?php foreach ($options as $value) {
		
			switch ( $value['type'] ) {
			
				case "set-open": ?>
					<a name="<?php echo $value['class']; ?>"></a>
					<div class="postbox">
						<h3><?php echo $value['name']; ?></h3>
						<div class="inside">
				<?php break;
				
				case "set-close": ?>
						</div><!--/ .inside -->
					</div><!--/ .postbox -->
					
					<div class="actions clearfix">
				
						<div class="action">
							<input class="button-primary" name="save" type="submit" value="Save changes" />
						</div>
						<div class="action back-to-top">
							<a href="#">Back to top</a>
						</div>
					
					</div><!--/ .actions -->
				<?php break;
					
				case "sub-header": ?>
					<div class="sub-header">
						<h4><?php echo $value['name']; ?></h4>
						<?php if ( $value['instructions'] ) : ?><p><?php echo $value['instructions']; ?></p><?php endif ?>
					</div><!--/ .option -->
				<?php break;
				
				case 'text': ?>
					<div class="option clearfix">
					<div class="option-title"><label><?php echo $value['name']; ?></label></div>
					<div class="option-input"><input name="<?php echo $value['id']; ?>" id="<?php echo $value['id']; ?>" type="<?php echo $value['type']; ?>" value="<?php echo (get_option( $value['id'] ) != "") ? stripslashes(get_option( $value['id'] )) : $value['std']; ?>" />
						<div class="description"><?php echo $value['desc']; ?></div>
					</div><!--/ .option-input -->
				</div><!--/ .option -->
				<?php break;
				
				case 'textarea': ?>
					<div class="option clearfix">
					<div class="option-title">
						<label><?php echo $value['name']; ?></label>
					</div>
					<div class="option-input">
						<?php $std = trim(array_key_exists('std', $value) ? $value['std'] : ''); ?>
						<textarea name="<?php echo $value['id']; ?>" type="<?php echo $value['type']; ?>" cols="10" rows="3"><?php echo (get_option( $value['id'] ) != "") ? stripslashes(get_option( $value['id'] )) : $std; ?></textarea>
						<div class="description"><?php echo $value['desc']; ?></div>
					</div><!--/ .option-input -->
				</div><!--/ .option -->
				<?php break;
				
				case 'select': ?>
					<div class="option clearfix">
					<div class="option-title"><label><?php echo $value['name']; ?></label></div>
					<div class="option-input">
						<select name="<?php echo $value['id']; ?>" id="<?php echo $value['id']; ?>">
						<?php foreach ($value['options'] as $option) { ?>
							<option<?php echo (get_option($value['id']) == $option) ? ' selected="selected"' : ''; ?>><?php echo $option; ?></option><?php } ?>
						</select>
						<div class="description"><?php echo $value['desc']; ?></div>
					</div><!--/ .option-input -->
				</div><!--/ .option -->
				<?php break;
				
				case 'checkbox': ?>
					<div class="option checkbox clearfix">
					<div class="option-title"><label><?php echo $value['name']; ?></label></div>
					<div class="option-input"><?php if(get_option($value['id'])){ $checked = "checked=\"checked\""; }else{ $checked = ""; } ?><input type="checkbox" name="<?php echo $value['id']; ?>" id="<?php echo $value['id']; ?>" value="true" <?php echo $checked; ?> />
						<div class="description"><?php echo $value['desc']; ?></div>
					</div><!--/ .option-input -->
				</div><!--/ .option -->
				<?php break;
				
				case 'colorpicker': ?>
					<div class="option colorpicker-wrap clearfix">
					<div class="option-title"><label><?php echo $value['name']; ?></label></div>
					<div class="option-input">
						<script language="javascript">
							(function($){
								var initLayout = function() {
									$('#colorSelector-<?php echo $value['id']; ?>').ColorPicker({
										color: '<?php if ( get_option( $value['id'] ) != "") { echo get_option( $value['id'] ); } else { echo $value['std']; } ?>',
										onShow: function (colpkr) {
											$(colpkr).fadeIn(200);
											return false;
										},
										onHide: function (colpkr) {
											$(colpkr).fadeOut(200);
											return false;
										},
										onChange: function (hsb, hex, rgb) {
											$('#colorSelector-<?php echo $value['id'] ?> div').css('backgroundColor', '#' + hex);
											$("#<?php echo $value['id']; ?>").attr('value', '#' + hex);
										}
									});
								};
								EYE.register(initLayout, 'init');
							})(jQuery)
						</script>
						<div id="colorContainer"><div id="colorSelector-<?php echo $value['id']; ?>" class="colorselector"><div style="background-color: <?php if ( get_option( $value['id'] ) != "") { echo get_option( $value['id'] ); } else { echo $value['std']; } ?>"></div></div></div>
							<input name="<?php echo $value['id']; ?>" id="<?php echo $value['id']; ?>" type="hidden" value="<?php if ( get_option( $value['id'] ) != "") { echo get_option( $value['id'] ); } else { echo $value['std']; } ?>" />    
						<div class="description"><?php echo $value['desc']; ?></div>
					</div><!--/ .option-input -->
				</div><!--/ .option -->
				<?php break;
				
				case 'upload': ?>
					<div class="option upload clearfix">
					<div class="option-title"><label><?php echo $value['name']; ?></label></div>
					<div class="option-input">
						<a class="button thickbox" href="media-upload.php?KeepThis=true&TB_iframe=true&width=640&height=700">Upload file</a>
						<input name="<?php echo $value['id']; ?>" id="<?php echo $value['id']; ?>" type="text" value="<?php if ( get_option( $value['id'] ) != "") { echo get_option( $value['id'] ); } else { echo $value['std']; } ?>" />
						<div class="description"><?php echo $value['desc']; ?></div>
					</div><!--/ .option-input -->
				</div><!--/ .option -->
				<?php break;
				
			}
		} ?>
			<input type="hidden" name="action" value="save" />
		</form>
	
		<div class="actions">
			<form method="post">
				<input class="button-secondary" name="reset" type="submit" value="Reset All Options" />
				<input type="hidden" name="action" value="reset" />
			</form>
		</div><!--/ .actions -->
	</div><!--/ #poststuff -->
	
	<?php
}

add_action('admin_menu', 'themejam_options'); 

# Enqueues all scripts and styles for front end.
function themejam_scripts_styles() {

	// Add js support for pages with commenting enabled.
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );
	wp_enqueue_script('thickbox');
	wp_enqueue_script('jquery');
	wp_enqueue_script('superfish', get_template_directory_uri().'/js/jquery.superfish.js', array('jquery'), '1.0');
	wp_enqueue_script('custom-js', get_template_directory_uri().'/js/custom.js', array('jquery'), '1.0');
	wp_enqueue_style('thickbox');

	$nb_custom_css = get_option('nb_custom_css');
	if(trim($nb_custom_css) != '') {
		wp_enqueue_style('custom-css', get_template_directory_uri() . '/styles/custom.php');
	}
	
	$style = isset($_GET['style']) ? $_GET['style'] : '';
	if ($style != '') {
		wp_enqueue_style($style, get_template_directory_uri() . '/styles/'.$style.'.css');
	} else {
		$nb_style = get_option("nb_stylesheet");
		wp_enqueue_style($nb_style, get_template_directory_uri() . '/styles/'.$nb_style.'.css');
	}
	
	$nb_custom_css = get_option('nb_custom_css');
	if(trim($nb_custom_css) != '') {
		echo '<style type="text/css">' . stripslashes($nb_custom_css) . '</style>';
	}

}
add_action( 'wp_enqueue_script', 'themejam_scripts_styles' );


# Displays navigation to next/previous post when applicable.
function themejam_post_nav() {
	global $post;

	// Don't print empty markup if there's nowhere to navigate.
	$previous = ( is_attachment() ) ? get_post( $post->post_parent ) : get_adjacent_post( false, '', true );
	$next     = get_adjacent_post( false, '', false );

	if ( ! $next && ! $previous )
		return;
	?>
	<div class="navigation post-navigation" role="navigation">
		<div class="nav-links">
			<div class="previous-entry"><?php previous_post_link( '%link', '<span class="meta-nav">&larr;</span> %title', 'Previous post link' ); ?></div>
			<div class="next-entry"><?php next_post_link( '%link', '%title <span class="meta-nav">&rarr;</span>', 'Next post link' ); ?></div>

		</div><!-- .nav-links -->
	</div><!-- .navigation -->
	<?php
}

function themejam_wp_title($sep) {
	if ( is_single() || is_page() ) {
		$title = single_post_title('', false);
	} elseif ( is_home() || is_front_page() ) {
		$title = get_bloginfo('name') . " | " . get_bloginfo('description');
	} elseif ( is_search() ) {
		$title = get_bloginfo('name') . " | Search results";
	} elseif ( is_404() ) {
		$title = get_bloginfo('name') . " | Not Found";
	} else {
		$title = get_bloginfo('name');// . wp_title('|', false);
	}
	return $title;
}
add_filter( 'wp_title', 'themejam_wp_title', 10, 2 );

function themejam_widgets() {

	// Register widget area: Home Sidebar
	register_sidebar(array(
		'name'          => 'Sidebar Widgets',
		'id'            => 'sidebar-widgets',
		'before_widget' => '<div class="widget clearfix %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4>',
		'after_title'   => '</h4>',
	));

	// Register widget area: Home Sidebar
	register_sidebar(array(
		'name'          => 'Footer Widgets',
		'id'            => 'footer-widgets',
		'before_widget' => '<div class="widget clearfix %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4>',
		'after_title'  => '</h4>',
	));
}
add_action('widgets_init', 'themejam_widgets');

?>